==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MSR_string.h <==
/* $Date: 1996/09/11 15:54:22 $  $Author: olli $  $Revision: 1.6 $ */

/**************************************************************************/
/* FILE:             MSR_string.h                                         */
/* Autor:            Karsten Morisse                                      */
/* Erstellt:         21/12/91                                             */
/* Letzte Aenderung: 07/09/94                                             */
/*                                                                        */
/* Dieses File enthaelt die Deklarationen des Modules MSR_string          */
/**************************************************************************/

#ifndef __MSR_string__
#define __MSR_string__


/**************************************************************************/
/* 			Konstanten					  */
/**************************************************************************/

#define MSRC_BUFSIZE	1024L	

/*** Interpretationsmodus f"ur Hyphenliste in text2tbl() ******************/

#define MSRC_NORMAL_MODE	0L
#define MSRC_CYCLIC_MODE	1L
#define MSRC_EMPTY_MODE	        2L


/**************************************************************************/
/* MAX_STR_LEN muss <= der groessten in STRSIZE darstellbaren Zahl sein.  */
/*									  */
/*	STRSIZE: short 		--> MAX_STR_LEN <= 32767 (= 2^15-1)	  */
/*	STRSIZE: unsigned short --> MAX_STR_LEN <= 65535 (= 2^16-1)	  */
/*	STRSIZE: long  		--> MAX_STR_LEN <= 2147483647 (= 2^31-1)  */
/*	STRSIZE: unsigned long  --> MAX_STR_LEN <= 4294967295 (= 2^32-1)  */
/*									  */
/**************************************************************************/

#define MAX_STR_LEN 2147483647	/* Maximale Stringlaenge		  */

/* Steuerung des Abgleichs mit dem MTRV_STRING_ASS_MEM                    */

#define MSRC_NO_UNIQUE    0L
#define MSRC_UNIQUE       1L



/**************************************************************************/
/* 			Typen						  */
/**************************************************************************/

/* STRSIZE darf _kein_ unsigned sein, da Funktionen wie MSR_strcmp auf
 * STRSIZE len >= 0 abfragen und der Fall len < 0 in diesen Routinen
 * auftreten kann! (kg) */

typedef long STRSIZE;		/* Typ fuer Stringlaenge		  */


/**************************************************************************/
/* 			Prototypen					  */
/**************************************************************************/

char     *MSR_str_chr     (	S_Pointer        str, 
				S_Pointer        pos, 
				char             setchar );
S_Pointer MSR_eval_strlen (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSR_eval_strmatch (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSR_eval_substring(	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSR_eval_tbl2text (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSR_eval_text2tbl (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSR_eval_text2list (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSR_nchar2string (	STRSIZE		 skip, 
				char		*string );
int       MSR_strcmp (		char		*s1, 
				char		*s2, 
				STRSIZE		 l1, 
				STRSIZE		 l2,
                                STRSIZE          *pos,
                                STRSIZE          *start );
int MSR_empty_string (		char		*s, 
				STRSIZE		 l );
int MSR_strcmp_skip (		char		*s1, 
				char		*s2, 
				STRSIZE		 l1, 
				STRSIZE		 l2, 
				STRSIZE		 skip,
                                STRSIZE          *pos,
                                STRSIZE          *start );
int MSR_search_string (		char		*s, 
				STRSIZE		 slen, 
				char		*m, 
				STRSIZE		 mlen, 
				STRSIZE		*skipped );
S_Pointer MSR_concat_catstring( S_Pointer	 s1, 
				S_Pointer	 s2 );
S_Pointer MSR_concat_cstring (	S_Pointer	 s, 
				char		*c,
				long             unique );
#ifdef DEADCODE
S_Pointer MSR_prefix_cstring (	char		*c, 
				S_Pointer	 s );
#endif
S_Pointer MSR_concat_mmmstring( S_Pointer	 s1, 
				S_Pointer	 s2 );
char *MSR_get_next_string_from_list (	S_Pointer	 list, 
					STRSIZE		 index, 
					STRSIZE		*len );

#ifndef NO_ENHANCED_MATCH

S_Pointer MSR_eval_search ( S_Pointer        s,
                            long             prev_func,
                            long             eval_type,
                            S_Pointer        exec );

S_Pointer MSR_eval_replace ( S_Pointer        s,
                             long             prev_func,
                             long             eval_type,
                             S_Pointer        exec );

#endif /* NO_ENHANCED_MATCH */


#endif /* __MSR_string__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MSR_string.h <==
/* $Date: 1999/06/02 07:22:12 $  $Author: kg $  $Revision: 1.7 $ */

/**************************************************************************/
/* FILE:             MSR_string.h                                         */
/* Autor:            Karsten Morisse                                      */
/* Erstellt:         21/12/91                                             */
/* Letzte Aenderung: 07/09/94                                             */
/*                                                                        */
/* Dieses File enthaelt die Deklarationen des Modules MSR_string          */
/**************************************************************************/

#ifndef __MSR_string__
#define __MSR_string__

#include "MTR_tree.h"
#include "MUP_constants.h"

/**************************************************************************/
/* 			Konstanten					  */
/**************************************************************************/

#define MSRC_BUFSIZE	1024

/* Interpretationsmodus f"ur Hyphenliste in text2tbl() ******************/

#define MSRC_NORMAL_MODE	0
#define MSRC_CYCLIC_MODE	1
#define MSRC_EMPTY_MODE	        2


/**************************************************************************/
/* MAX_STR_LEN muss <= der groessten in STRSIZE darstellbaren Zahl sein.  */
/*			                                                  */
/*	STRSIZE: short 		--> MAX_STR_LEN <= 32767 (= 2^15-1)       */
/*	STRSIZE: unsigned short --> MAX_STR_LEN <= 65535 (= 2^16-1)       */
/*	STRSIZE: long  		--> MAX_STR_LEN <= 2147483647 (= 2^31-1)  */
/*	STRSIZE: unsigned long  --> MAX_STR_LEN <= 4294967295 (= 2^32-1)  */
/*									  */
/**************************************************************************/

#define MAX_STR_LEN 2147483647	/* Maximale Stringlaenge */

/* Steuerung des Abgleichs mit dem MTRV_STRING_ASS_MEM */

#define MSRC_NO_UNIQUE    0
#define MSRC_UNIQUE       1




/**************************************************************************/
/* 			Prototypen	                                  */
/**************************************************************************/

char     *MSR_str_chr     (	S_Pointer        str,
				S_Pointer        pos,
				char             setchar );
S_Pointer MSR_eval_strmatch (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSR_eval_substring(	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSR_eval_tbl2text (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSR_eval_text2tbl (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MSR_eval_text2list (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );

S_Pointer MSR_nchar2string (	STRSIZE		 skip,
				char		*string );
int       MSR_strcmp (		char		*s1,
				char		*s2,
				STRSIZE		 l1,
				STRSIZE		 l2,
                                STRSIZE          *pos,
                                STRSIZE          *start );
int MSR_empty_string (		char		*s,
				STRSIZE		 l );
int MSR_strcmp_skip (		char		*s1,
				char		*s2,
				STRSIZE		 l1,
				STRSIZE		 l2,
				STRSIZE		 skip,
                                STRSIZE          *pos,
                                STRSIZE          *start );
int MSR_search_string (		char		*s,
				STRSIZE		 slen,
				char		*m,
				STRSIZE		 mlen,
				STRSIZE		*skipped );
S_Pointer MSR_concat_catstring( S_Pointer	 s1,
				S_Pointer	 s2 );
S_Pointer MSR_concat_cstring (	S_Pointer	 s,
				char		*c,
				long             unique );
#ifdef DEADCODE
S_Pointer MSR_prefix_cstring (	char		*c,
				S_Pointer	 s );
#endif
S_Pointer MSR_concat_mmmstring( S_Pointer	 s1,
				S_Pointer	 s2 );
char *MSR_get_next_string_from_list (	S_Pointer	 list,
					STRSIZE		 index,
					STRSIZE		*len );

/**
    Return the underlying C-String of the given S\_Pointer of type CAT\_STRING
    @param   stringi  A S\_Pointer of type CAT\_STRING
    @return  A pointer to the underlying C-String
*/
const char* MSR_get_string( const S_Pointer stringi ) ;


// Implementation

inline const char* MSR_get_string( const S_Pointer stringi )
{
   assert( MTR_cat(stringi) == CAT_STRING ) ;
   const S_Pointer *sohn = MMMP( (S_Pointer *) &stringi, 0) ;
   return( MTR_get_string( *sohn ) ) ;
}

#endif /* __MSR_string__ */
